import {
  Form,
  Modal,
  Row,
  Col,
  Input,
  DatePicker,
  Upload,
  Button,
  Divider,
} from 'antd';
import ModuleTitle from '../../../components/ModuleTitle/moduleTitle';
import { CloudUploadOutlined } from '@ant-design/icons';

const ContractModal = (props) => {
  const { title, visible, handleOk, handleCancel } = props;
  const [form] = Form.useForm();

  const UploadProps = {
    action: 'https://www.mocky.io/v2/5cc8019d300000980a055e76',
    onChange({ file, fileList }) {
      if (file.status !== 'uploading') {
        console.log(file, fileList);
      }
    },
    defaultFileList: [
      {
        uid: '1',
        name: 'xxx.png',
        status: 'uploading',
        url: 'http://www.baidu.com/xxx.png',
        percent: 33,
      },
      {
        uid: '2',
        name: 'yyy.png',
        status: 'done',
        url: 'http://www.baidu.com/yyy.png',
      },
      {
        uid: '3',
        name: 'zzz.png',
        status: 'error',
        response: 'Server Error 500',
        // custom error message to show
        url: 'http://www.baidu.com/zzz.png',
      },
    ],
  };

  return (
    <Modal
      width={'85%'}
      title={title}
      open={visible}
      okText="提交"
      cancelText="返回"
      onOk={handleOk}
      onCancel={handleCancel}
    >
      <Divider />
      <ModuleTitle title="合同信息" />
      <Form labelCol={{ span: 7 }} wrapperCol={{ span: 17 }}>
        <Row>
          <Col span={10} offset={1}>
            <Form.Item
              name="email"
              label="所属公司："
              tooltip="所属公司"
              rules={[
                {
                  required: true,
                  message: '请填写所属公司',
                },
              ]}
            >
              <Input />
            </Form.Item>
            <Form.Item
              name="email"
              label="合同名称："
              tooltip="合同名称"
              rules={[
                {
                  required: true,
                  message: '请填写合同名称',
                },
              ]}
            >
              <Input />
            </Form.Item>
            <Form.Item
              name="email"
              label="合同生效日期："
              rules={[
                {
                  required: true,
                  message: '请填写合同名称',
                },
              ]}
            >
              <DatePicker />
            </Form.Item>
            <Form.Item
              name="email"
              label="甲方："
              rules={[
                {
                  required: true,
                  message: '请选择甲方',
                },
              ]}
            >
              <DatePicker />
            </Form.Item>
            <Form.Item
              name="email"
              label="丙方（及其他）："
              rules={[
                {
                  required: true,
                  message: '请选择（支持多选）',
                },
              ]}
            >
              <DatePicker />
            </Form.Item>
            <Form.Item
              name="email"
              label="签约承办部门："
              rules={[
                {
                  required: true,
                  message: '请选择签约承办部门',
                },
              ]}
            >
              <DatePicker />
            </Form.Item>
          </Col>
          <Col span={10}>
            <Form.Item
              name="email"
              label="所属部门："
              rules={[
                {
                  required: true,
                  message: '请选择所属部门',
                },
              ]}
            >
              <Input />
            </Form.Item>
            <Form.Item name="email" label="合同编号：">
              <Input disabled />
            </Form.Item>

            <Form.Item label="合同总价款：">
              <Row gutter={8}>
                <Col span={12}>
                  <Form.Item
                    style={{ marginBottom: 0 }}
                    name="email"
                    rules={[
                      {
                        required: true,
                        message: '请输入合同总价款',
                      },
                    ]}
                  >
                    <Input />
                  </Form.Item>
                </Col>
                <Col span={12}>
                  <div>万元</div>
                </Col>
              </Row>
            </Form.Item>

            <Form.Item name="email" label="项目编号：">
              <Input disabled />
            </Form.Item>
            <Form.Item
              name="email"
              label="乙方："
              rules={[
                {
                  required: true,
                  message: '请选择乙方',
                },
              ]}
            >
              <Input />
            </Form.Item>
            <Form.Item
              name="email"
              label="经办人："
              rules={[
                {
                  required: true,
                  message: '请选择经办人',
                },
              ]}
            >
              <Input />
            </Form.Item>
          </Col>
        </Row>
        <Form.Item name="email" label="合同履行情况：" labelCol={{ span: 4 }}>
          <Input.TextArea />
        </Form.Item>
        <Form.Item name="email" label="合同上传：" labelCol={{ span: 4 }}>
          <Upload {...UploadProps}>
            <Button icon={<CloudUploadOutlined />}>Upload</Button>
          </Upload>
        </Form.Item>
        <Row>
          <Col span={10} offset={1}>
            <Form.Item name="email" label="创建人：">
              <Input disabled />
            </Form.Item>
          </Col>
          <Col span={10}>
            <Form.Item name="email" label="创建时间：">
              <Input disabled />
            </Form.Item>
          </Col>
        </Row>
      </Form>
      <Divider />
    </Modal>
  );
};
export default ContractModal;
